Groups | Search | Server Info | Keyboard shortcuts | Login | Register [http] [https] [nntp] [nntps]
Groups > comp.lang.python.announce > #2840 > unrolled thread
| Started by | Robert McLeod <robbmcleod@gmail.com> |
|---|---|
| First post | 2018-05-01 13:31 -0700 |
| Last post | 2018-05-01 13:31 -0700 |
| Articles | 1 — 1 participant |
Back to article view | Back to comp.lang.python.announce
This discussion starts older than the indexed window; earlier articles aren't shown. The article labeled Started by
below is the oldest one visible, not the original post.
ANN: NumExpr 2.6.5 Robert McLeod <robbmcleod@gmail.com> - 2018-05-01 13:31 -0700
| From | Robert McLeod <robbmcleod@gmail.com> |
|---|---|
| Date | 2018-05-01 13:31 -0700 |
| Subject | ANN: NumExpr 2.6.5 |
| Message-ID | <mailman.51.1525264485.2789.python-announce-list@python.org> |
========================== Announcing Numexpr 2.6.5 ========================== Hi everyone, This is primarily an incremental performance improvement release, especially with regards to improving import times of downstream packages (e.g. `pandas`, `tables`, `sympy`). Import times have been reduced from ~300 ms to ~100 ms through removing a `pkg_resources` import and making the `cpuinfo` import lazy. The maximum number of threads is now set at import-time, similar to `numba`, by setting an environment variable 'NUMEXPR_MAX_THREADS'. The runtime number of threads can still be reduced by calling `numexpr.set_num_threads(N)`. DEPRECATION WARNING: The variable `numexpr.is_cpu_amd_intel` has been set to a dummy value of `False`. This variable may be removed in the future. Project documentation is available at: http://numexpr.readthedocs.io/ Changes from 2.6.4 to 2.6.5 --------------------------- - The maximum thread count can now be set at import-time by setting the environment variable 'NUMEXPR_MAX_THREADS'. The default number of max threads was lowered from 4096 (which was deemed excessive) to 64. - A number of imports were removed (pkg_resources) or made lazy (cpuinfo) in order to speed load-times for downstream packages (such as `pandas`, `sympy`, and `tables`). Import time has dropped from about 330 ms to 90 ms. Thanks to Jason Sachs for pointing out the source of the slow-down. - Thanks to Alvaro Lopez Ortega for updates to benchmarks to be compatible with Python 3. - Travis and AppVeyor now fail if the test module fails or errors. - Thanks to Mahdi Ben Jelloul for a patch that removed a bug where constants in `where` calls would raise a ValueError. - Fixed a bug whereby all-constant power operations would lead to infinite recursion. -- Robert McLeod, Ph.D. robbmcleod@gmail.com robbmcleod@protonmail.com robert.mcleod@hitachi-hhtc.ca www.entropyreduction.al
Back to top | Article view | comp.lang.python.announce
csiph-web